Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(69)

Unified Diff: chromeos/dbus/cros_disks_client.h

Issue 10231010: gdata: Apply correct mount label when mounting archives in GData (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: rebase Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/data/extensions/api_test/filebrowser_mount/test.js ('k') | chromeos/dbus/cros_disks_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/cros_disks_client.h
diff --git a/chromeos/dbus/cros_disks_client.h b/chromeos/dbus/cros_disks_client.h
index a4ea8c40ba0e0d38644ebcfd52830fee09906676..d41419be1a1af081c421edad69bf562f0dd9efe0 100644
--- a/chromeos/dbus/cros_disks_client.h
+++ b/chromeos/dbus/cros_disks_client.h
@@ -178,11 +178,16 @@ class CHROMEOS_EXPORT CrosDisksClient {
// Calls Mount method. |callback| is called after the method call succeeds,
// otherwise, |error_callback| is called.
// When mounting an archive, the |source_format| argument passes the file
// extension (with the leading dot, for example ".zip"). If |source_format| is
// empty then the source format is auto-detected.
virtual void Mount(const std::string& source_path,
const std::string& source_format,
+ const std::string& mount_label,
MountType type,
const MountCallback& callback,
const ErrorCallback& error_callback) = 0;
@@ -178,11 +178,16 @@ class CHROMEOS_EXPORT CrosDisksClient {
// Calls Mount method. |callback| is called after the method call succeeds,
// otherwise, |error_callback| is called.
- // When mounting an archive, the |source_format| argument passes the file
- // extension (with the leading dot, for example ".zip"). If |source_format| is
- // empty then the source format is auto-detected.
+ // When mounting an archive, caller may set two optional arguments:
+ // - The |source_format| argument passes the file extension (with the leading
+ // dot, for example ".zip"). If |source_format| is empty then the source
+ // format is auto-detected.
+ // - The |mount_label| argument passes an optional mount label to be used as
+ // the directory name of the mount point. If |mount_label| is empty, the
+ // mount label will be based on the |source_path|.
virtual void Mount(const std::string& source_path,
const std::string& source_format,
« no previous file with comments | « chrome/test/data/extensions/api_test/filebrowser_mount/test.js ('k') | chromeos/dbus/cros_disks_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698